import io
import PIL
import pickle
import requests
from sklearn.preprocessing import normalize
import os

from botnoi import getbow as gb
tfidfpath = os.path.join(os.path.dirname(gb.__file__),'botnoitfidf_v1.mod')
modtfidf = pickle.load(open(tfidfpath,'rb'))
print('load model tfidf')
def extract_bowtfidf(textList):
  '''extract bow with tfidf vectors'''

  
  feat = gb.sentencevector(textList,modtfidf)
  feat = normalize(feat)
  return feat

from botnoi import getw2v as gw
w2vpath = os.path.join(os.path.dirname(gw.__file__),'botnoiw2v_small.mod')
modw2v = pickle.load(open(w2vpath,'rb'))
print('load model w2v')
def extract_w2vlight(textList):
  '''extract w2v vectors'''
  
  feat = gw.sentencevector(textList,modw2v)
  feat = normalize(feat)
  return feat

from botnoi import nlpcorrection as nc
sencor = os.path.join(os.path.dirname(nc.__file__),'botnoidict.p')
modworddict = pickle.load(open(sencor,'rb'))
print('load word dict')
def getsentencescore(sentence):
  '''get sentence score'''
  
  res = nc.sentencescore(sentence,modworddict)
  return res


def printhello():
  print('hello')






from setuptools import setup, find_packages

with open('README.md') as readme_file:
    README = readme_file.read()

with open('HISTORY.md') as history_file:
    HISTORY = history_file.read()

setup_args = dict(
    name='botnoi',
    version='0.5.9',
    description='BOTNOI',
    long_description_content_type="text/markdown",
    long_description=README + '\n\n' + HISTORY,
    license='MIT',
    packages=find_packages(),
    author='Winn Voravuthikunchai',
    author_email='vwinnv@gmail.com',
    keywords=['NLP'],
    include_package_data=True,
    url='https://github.com/winn/botnoi',
    download_url='https://pypi.org/project/botnoinlp/'
)

installrequires = [
'pandas',
'pillow',
'pythainlp',
'gensim',
'pymongo[tls,srv]',
'SpeechRecognition',
'wave',
'audioread',
'line-bot-sdk',
'gspread==3.6.0'
]

if __name__ == '__main__':
    setup(**setup_args, install_requires=installrequires)



from pymongo import MongoClient
class userstate():
    def __init__(self,mongodbcollection):
        self.dbcollection = mongodbcollection
    def setuserstate(self,user, userstate):
        try:
            res = self.dbcollection.update_one({"userId": user}, {"$set": userstate}, upsert=True)
        except:
            res = self.dbcollection.insert_one(userstate)
        return res

    def getuserstate(self,userid):
        userstate = self.dbcollection.find_one({"userId": userid})
        if userstate is None:
            userstate = {"userId": userid}
            self.dbcollection.insert_one(userstate)
        return userstate



